SizeConfig

Enum SizeConfig 

pub enum SizeConfig {
    Default,
    Ratio(f64),
    Fixed(usize),
}
Helper option to describe the size of a wrapper, relative to a wrapped object.

Variants



Default

Use the size of the source dataset.



Ratio(f64)

Use the size as a ratio of the source dataset size.

Must be >= 0.



Fixed(usize)

Use a fixed size.

Implementations

Source

impl SizeConfig

pub fn source() -> Self

Construct a source which will have the same size as the source dataset.

pub fn resolve(self, source_size: usize) -> usize

Resolve the effective size.

Arguments
  • source_size: the size of the source dataset.
Returns

The resolved size of the wrapper dataset.