pub enum SizeConfig {
Default,
Ratio(f64),
Fixed(usize),
}Expand description
Helper option to describe the size of a wrapper, relative to a wrapped object.
Variants
Default
Use the size of the source dataset.
Ratio(f64)
Use the size as a ratio of the source dataset size.
Must be >= 0.
Fixed(usize)
Use a fixed size.
Implementations
Sourceimpl SizeConfig
impl SizeConfig